@@ -77,8 +77,8 @@ class MBTilesCache(TileCacheBase):
 
     def ensure_mbtile(self):
         if not os.path.exists(self.mbtile_file):
-            with FileLock(self.mbtile_file + '.init.lck',
-                          remove_on_unlock=REMOVE_ON_UNLOCK, directory_permissions=self.directory_permissions):
+            with FileLock(self.mbtile_file + '.init.lck', remove_on_unlock=REMOVE_ON_UNLOCK,
+                          directory_permissions=self.directory_permissions, file_permissions=self.file_permissions):
                 if not os.path.exists(self.mbtile_file):
                     ensure_directory(self.mbtile_file, self.directory_permissions)
                     self._initialize_mbtile()
@@ -272,7 +272,7 @@ class MBTilesCache(TileCacheBase):
 
         return loaded_tiles == len(tile_dict)
 
-    def remove_tile(self, tile):
+    def remove_tile(self, tile, dimensions=None):
         cursor = self.db.cursor()
         cursor.execute(
             "DELETE FROM tiles WHERE (tile_column = ? AND tile_row = ? AND zoom_level = ?)",
@@ -282,8 +282,8 @@ class MBTilesCache(TileCacheBase):
             return True
         return False
 
-    def remove_level_tiles_before(self, level, timestamp):
-        if timestamp == 0:
+    def remove_level_tiles_before(self, level, timestamp=None, remove_all=False):
+        if remove_all:
             cursor = self.db.cursor()
             cursor.execute(
                 "DELETE FROM tiles WHERE (zoom_level = ?)",
@@ -408,9 +408,9 @@ class MBTilesLevelCache(TileCacheBase):
     def load_tile_metadata(self, tile, dimensions=None):
         self.load_tile(tile, dimensions=dimensions)
 
-    def remove_level_tiles_before(self, level, timestamp):
+    def remove_level_tiles_before(self, level, timestamp=None, remove_all=False):
         level_cache = self._get_level(level)
-        if timestamp == 0:
+        if remove_all:
             level_cache.cleanup()
             os.unlink(level_cache.mbtile_file)
             for file in glob.glob("%s-*" % glob.escape(level_cache.mbtile_file)):
