@@ -16,34 +16,38 @@
 server = ['wms', 'tms', 'kml']
 
 wms = dict(
-    image_formats = ['image/png', 'image/jpeg', 'image/gif', 'image/GeoTIFF', 'image/tiff'],
-    srs = set(['EPSG:4326', 'EPSG:4258', 'CRS:84', 'EPSG:900913', 'EPSG:3857']),
-    strict = False,
-    request_parser = 'default',
-    client_request = 'default',
-    concurrent_layer_renderer = 1,
-    max_output_pixels = 4000*4000,
+    image_formats=['image/png', 'image/jpeg', 'image/gif', 'image/GeoTIFF', 'image/tiff'],
+    srs=set(['EPSG:4326', 'EPSG:4258', 'CRS:84', 'EPSG:900913', 'EPSG:3857']),
+    strict=False,
+    request_parser='default',
+    client_request='default',
+    concurrent_layer_renderer=1,
+    max_output_pixels=4000*4000,
 )
 debug_mode = False
 
+background = dict(
+    url="https://tile.openstreetmap.org/{z}/{x}/{y}.png"
+)
+
 srs = dict(
     # user sets
-    axis_order_ne = set(),
-    axis_order_en = set(),
+    axis_order_ne=set(),
+    axis_order_en=set(),
     # default sets, both will be combined in config:load_base_config
-    axis_order_ne_ = set(['EPSG:4326', 'EPSG:4258', 'EPSG:31466', 'EPSG:31467', 'EPSG:31468']),
-    axis_order_en_ = set(['CRS:84', 'EPSG:900913', 'EPSG:25831', 'EPSG:25832', 'EPSG:25833']),
+    axis_order_ne_=set(['EPSG:4326', 'EPSG:4258', 'EPSG:31466', 'EPSG:31467', 'EPSG:31468']),
+    axis_order_en_=set(['CRS:84', 'EPSG:900913', 'EPSG:25831', 'EPSG:25832', 'EPSG:25833']),
 )
 
 image = dict(
     # nearest, bilinear, bicubic
-    resampling_method = 'bicubic',
-    jpeg_quality = 90,
-    stretch_factor = 1.15,
-    max_shrink_factor = 4.0,
-    paletted = True,
-    transparent_color_tolerance = 5,
-    font_dir = None,
+    resampling_method='bicubic',
+    jpeg_quality=90,
+    stretch_factor=1.15,
+    max_shrink_factor=4.0,
+    paletted=True,
+    transparent_color_tolerance=5,
+    font_dir=None,
 )
 # number of concurrent requests to a tile source
 
@@ -55,19 +59,19 @@ log_conf = 'log.ini'
 template_dir = None
 
 cache = dict(
-    base_dir = './cache_data',
-    lock_dir = './cache_data/tile_locks',
-    max_tile_limit = 500,
-    concurrent_tile_creators = 2,
-    meta_size = (4, 4),
-    meta_buffer = 80,
-    minimize_meta_requests = False,
-    link_single_color_images = False,
-    sqlite_timeout = 30,
+    base_dir='./cache_data',
+    lock_dir='./cache_data/tile_locks',
+    max_tile_limit=500,
+    concurrent_tile_creators=2,
+    meta_size=(4, 4),
+    meta_buffer=80,
+    minimize_meta_requests=False,
+    link_single_color_images=False,
+    sqlite_timeout=30,
 )
 
 grid = dict(
-    tile_size = (256, 256),
+    tile_size=(256, 256),
 )
 
 grids = dict(
@@ -83,16 +87,16 @@ grids = dict(
 )
 
 tiles = dict(
-    expires_hours = 72,
+    expires_hours=72,
 )
 
 http = dict(
-    ssl_ca_certs = None,
-    ssl_no_cert_checks = False,
-    client_timeout = 60,
-    concurrent_requests = 0,
-    method = 'AUTO',
-    access_control_allow_origin = '*',
-    hide_error_details = True,
-    manage_cookies = False,
+    ssl_ca_certs=None,
+    ssl_no_cert_checks=False,
+    client_timeout=60,
+    concurrent_requests=0,
+    method='AUTO',
+    access_control_allow_origin='*',
+    hide_error_details=True,
+    manage_cookies=False,
 )
