@@ -72,7 +72,7 @@ class TestResolution(object):
         assert res[9] == pytest.approx(10)
 
     def test_bbox_levels(self):
-        conf = dict(bbox=[0,40,15,50], num_levels=10, tile_size=(256, 256))
+        conf = dict(bbox=[0, 40, 15, 50], num_levels=10, tile_size=(256, 256))
         res = resolutions(**conf)
         assert len(res) == 10
         assert res[0] == pytest.approx(15/256)
@@ -128,6 +128,7 @@ def test_metagrid_tiles():
         [((0, 3, 2), (0, 0)), ((1, 3, 2), (256, 0)),
          ((0, 2, 2), (0, 256)), ((1, 2, 2), (256, 256))]
 
+
 def test_metagrid_tiles_w_meta_size():
     mgrid = MetaGrid(grid=TileGrid(), meta_size=(4, 2))
     assert list(mgrid.meta_tile((1, 2, 2)).tile_patterns) == \
@@ -136,6 +137,7 @@ def test_metagrid_tiles_w_meta_size():
          ((0, 2, 2), (0, 256)), ((1, 2, 2), (256, 256)),
          ((2, 2, 2), (512, 256)), ((3, 2, 2), (768, 256))]
 
+
 class TestMetaGridGeodetic(object):
     def setup_method(self):
         self.mgrid = MetaGrid(grid=tile_grid('EPSG:4326'), meta_size=(2, 2), meta_buffer=10)
@@ -143,7 +145,7 @@ class TestMetaGridGeodetic(object):
     def test_meta_bbox_level_0(self):
         assert self.mgrid._meta_bbox((0, 0, 0)) == ((-180, -90, 180, 90), (0, 0, 0, -128))
         assert (self.mgrid._meta_bbox((0, 0, 0), limit_to_bbox=False) ==
-            ((-194.0625, -104.0625, 194.0625, 284.0625), (10, 10, 10, 10)))
+                ((-194.0625, -104.0625, 194.0625, 284.0625), (10, 10, 10, 10)))
 
         assert self.mgrid.meta_tile((0, 0, 0)).size == (256, 128)
 
@@ -156,23 +158,24 @@ class TestMetaGridGeodetic(object):
     def test_meta_bbox_level_1(self):
         assert (self.mgrid._meta_bbox((0, 0, 1)) == ((-180, -90, 180, 90), (0, 0, 0, 0)))
         assert (self.mgrid._meta_bbox((0, 0, 1), limit_to_bbox=False) ==
-            ((-187.03125, -97.03125, 187.03125, 97.03125), (10, 10, 10, 10)))
+                ((-187.03125, -97.03125, 187.03125, 97.03125), (10, 10, 10, 10)))
         assert (self.mgrid.meta_tile((0, 0, 1)).size == (512, 256))
 
     def test_tiles_level_1(self):
         assert (list(self.mgrid.meta_tile((0, 0, 1)).tile_patterns) ==
-            [
+                [
                 ((0, 0, 1), (0, 0)),
                 ((1, 0, 1), (256, 0))
-            ])
+                ])
+
     def test_tile_list_level_1(self):
         assert (list(self.mgrid.tile_list((0, 0, 1))) ==
-            [(0, 0, 1), (1, 0, 1)])
+                [(0, 0, 1), (1, 0, 1)])
 
     def test_meta_bbox_level_2(self):
         assert (self.mgrid._meta_bbox((0, 0, 2)) == ((-180, -90, 3.515625, 90), (0, 0, 10, 0)))
         assert (self.mgrid._meta_bbox((0, 0, 2), limit_to_bbox=False) ==
-            ((-183.515625, -93.515625, 3.515625, 93.515625), (10, 10, 10, 10)))
+                ((-183.515625, -93.515625, 3.515625, 93.515625), (10, 10, 10, 10)))
         assert (self.mgrid.meta_tile((0, 0, 2)).size == (522, 512))
 
         assert (self.mgrid._meta_bbox((2, 0, 2)) == ((-3.515625, -90, 180, 90), (10, 0, 0, 0)))
@@ -181,42 +184,43 @@ class TestMetaGridGeodetic(object):
         assert meta_tile.grid_size == (2, 2)
 
     def test_tiles_level_2(self):
-         assert (list(self.mgrid.meta_tile((0, 0, 2)).tile_patterns) ==
-            [
+        assert (list(self.mgrid.meta_tile((0, 0, 2)).tile_patterns) ==
+                [
                 ((0, 1, 2), (0, 0)),
                 ((1, 1, 2), (256, 0)),
                 ((0, 0, 2), (0, 256)),
                 ((1, 0, 2), (256, 256)),
-            ])
-         assert (list(self.mgrid.meta_tile((2, 0, 2)).tile_patterns) ==
-            [
+                ])
+        assert (list(self.mgrid.meta_tile((2, 0, 2)).tile_patterns) ==
+                [
                 ((2, 1, 2), (10, 0)),
                 ((3, 1, 2), (266, 0)),
                 ((2, 0, 2), (10, 256)),
                 ((3, 0, 2), (266, 256)),
-            ])
+                ])
 
     def test_tile_list_level_2(self):
-         assert (list(self.mgrid.tile_list((0, 0, 2))) ==
-            [(0, 1, 2), (1, 1, 2), (0, 0, 2), (1, 0, 2)])
-         assert (list(self.mgrid.tile_list((1, 1, 2))) ==
-            [(0, 1, 2), (1, 1, 2), (0, 0, 2), (1, 0, 2)])
+        assert (list(self.mgrid.tile_list((0, 0, 2))) ==
+                [(0, 1, 2), (1, 1, 2), (0, 0, 2), (1, 0, 2)])
+        assert (list(self.mgrid.tile_list((1, 1, 2))) ==
+                [(0, 1, 2), (1, 1, 2), (0, 0, 2), (1, 0, 2)])
 
     def test_tiles_level_3(self):
-         assert (list(self.mgrid.meta_tile((2, 0, 3)).tile_patterns) ==
-            [
+        assert (list(self.mgrid.meta_tile((2, 0, 3)).tile_patterns) ==
+                [
                 ((2, 1, 3), (10, 10)),
                 ((3, 1, 3), (266, 10)),
                 ((2, 0, 3), (10, 266)),
                 ((3, 0, 3), (266, 266)),
-            ])
-         assert (list(self.mgrid.meta_tile((2, 2, 3)).tile_patterns) ==
-            [
+                ])
+        assert (list(self.mgrid.meta_tile((2, 2, 3)).tile_patterns) ==
+                [
                 ((2, 3, 3), (10, 0)),
                 ((3, 3, 3), (266, 0)),
                 ((2, 2, 3), (10, 256)),
                 ((3, 2, 3), (266, 256)),
-            ])
+                ])
+
 
 class TestMetaGridGeodeticUL(object):
     def setup_method(self):
@@ -230,21 +234,20 @@ class TestMetaGridGeodeticUL(object):
         assert meta_tile.grid_size == (1, 1)
         assert meta_tile.tile_patterns == [((0, 0, 0), (0, 0))]
 
-
     def test_tiles_level_1(self):
         meta_tile = self.mgrid.meta_tile((0, 0, 1))
         assert meta_tile.bbox == pytest.approx((-180, -90, 180, 90))
         assert meta_tile.size == (512, 256)
         assert meta_tile.grid_size == (2, 1)
         assert (list(meta_tile.tile_patterns) ==
-            [
+                [
                 ((0, 0, 1), (0, 0)),
                 ((1, 0, 1), (256, 0))
-            ])
+                ])
 
     def test_tile_list_level_1(self):
         assert (list(self.mgrid.tile_list((0, 0, 1))) ==
-            [(0, 0, 1), (1, 0, 1)])
+                [(0, 0, 1), (1, 0, 1)])
 
     def test_tiles_level_2(self):
         meta_tile = self.mgrid.meta_tile((0, 0, 2))
@@ -252,25 +255,25 @@ class TestMetaGridGeodeticUL(object):
         assert meta_tile.size == (522, 512)
         assert meta_tile.grid_size == (2, 2)
         assert (meta_tile.tile_patterns ==
-            [
-                ((0, 0, 2), (0, 0)),
-                ((1, 0, 2), (256, 0)),
-                ((0, 1, 2), (0, 256)),
-                ((1, 1, 2), (256, 256)),
-            ])
+                [
+                    ((0, 0, 2), (0, 0)),
+                    ((1, 0, 2), (256, 0)),
+                    ((0, 1, 2), (0, 256)),
+                    ((1, 1, 2), (256, 256)),
+                ])
         assert (list(self.mgrid.meta_tile((2, 0, 2)).tile_patterns) ==
-            [
+                [
                 ((2, 0, 2), (10, 0)),
                 ((3, 0, 2), (266, 0)),
                 ((2, 1, 2), (10, 256)),
                 ((3, 1, 2), (266, 256)),
-            ])
+                ])
 
     def test_tile_list_level_2(self):
         assert (list(self.mgrid.tile_list((0, 0, 2))) ==
-            [(0, 0, 2), (1, 0, 2), (0, 1, 2), (1, 1, 2)])
+                [(0, 0, 2), (1, 0, 2), (0, 1, 2), (1, 1, 2)])
         assert (list(self.mgrid.tile_list((1, 1, 2))) ==
-            [(0, 0, 2), (1, 0, 2), (0, 1, 2), (1, 1, 2)])
+                [(0, 0, 2), (1, 0, 2), (0, 1, 2), (1, 1, 2)])
 
     def test_tiles_level_3(self):
         meta_tile = self.mgrid.meta_tile((2, 0, 3))
@@ -278,24 +281,25 @@ class TestMetaGridGeodeticUL(object):
         assert meta_tile.size == (532, 522)
         assert meta_tile.grid_size == (2, 2)
         assert (list(self.mgrid.meta_tile((2, 0, 3)).tile_patterns) ==
-            [
+                [
                 ((2, 0, 3), (10, 0)),
                 ((3, 0, 3), (266, 0)),
                 ((2, 1, 3), (10, 256)),
                 ((3, 1, 3), (266, 256)),
-            ])
+                ])
         assert (list(self.mgrid.meta_tile((2, 2, 3)).tile_patterns) ==
-            [
+                [
                 ((2, 2, 3), (10, 10)),
                 ((3, 2, 3), (266, 10)),
                 ((2, 3, 3), (10, 266)),
                 ((3, 3, 3), (266, 266)),
-            ])
+                ])
 
 
 class TestMetaTile(object):
     def setup_method(self):
         self.mgrid = MetaGrid(grid=tile_grid('EPSG:4326'), meta_size=(2, 2), meta_buffer=10)
+
     def test_meta_tile(self):
         meta_tile = self.mgrid.meta_tile((2, 0, 2))
         assert meta_tile.size == (522, 512)
@@ -316,10 +320,12 @@ class TestMetaTile(object):
         assert meta_tile.size == (1024, 512)
         assert meta_tile.grid_size == (4, 2)
 
+
 class TestMetaTileSQRT2(object):
     def setup_method(self):
         self.grid = tile_grid('EPSG:4326', res_factor='sqrt2')
         self.mgrid = MetaGrid(grid=self.grid, meta_size=(4, 4), meta_buffer=10)
+
     def test_meta_tile(self):
         meta_tile = self.mgrid.meta_tile((0, 0, 8))
         assert meta_tile.size == (1034, 1034)
@@ -340,8 +346,8 @@ class TestMetaTileSQRT2(object):
         assert meta_tile.bbox == pytest.approx((-180.0, -90, 180.0, 90.0))
         assert meta_tile.size == (724, 362)
         assert meta_tile.tile_patterns == [((0, 1, 3), (0, -149)), ((1, 1, 3), (256, -149)),
-            ((2, 1, 3), (512, -149)), ((0, 0, 3), (0, 107)), ((1, 0, 3), (256, 107)),
-            ((2, 0, 3), (512, 107))]
+                                           ((2, 1, 3), (512, -149)), ((0, 0, 3), (0, 107)), ((1, 0, 3), (256, 107)),
+                                           ((2, 0, 3), (512, 107))]
 
     def test_metatile_non_default_meta_size(self):
         mgrid = MetaGrid(grid=self.grid, meta_size=(4, 2), meta_buffer=0)
@@ -350,10 +356,8 @@ class TestMetaTileSQRT2(object):
         assert meta_tile.size == (1024, 512)
         assert meta_tile.grid_size == (4, 2)
         assert meta_tile.tile_patterns == [((4, 3, 6), (0, 0)), ((5, 3, 6), (256, 0)),
-            ((6, 3, 6), (512, 0)), ((7, 3, 6), (768, 0)), ((4, 2, 6), (0, 256)),
-            ((5, 2, 6), (256, 256)), ((6, 2, 6), (512, 256)), ((7, 2, 6), (768, 256))]
-
-
+                                           ((6, 3, 6), (512, 0)), ((7, 3, 6), (768, 0)), ((4, 2, 6), (0, 256)),
+                                           ((5, 2, 6), (256, 256)), ((6, 2, 6), (512, 256)), ((7, 2, 6), (768, 256))]
 
 
 class TestMinimalMetaTile(object):
@@ -364,49 +368,49 @@ class TestMinimalMetaTile(object):
         sgrid = self.mgrid.minimal_meta_tile([(0, 0, 2), (1, 0, 2)])
         assert sgrid.grid_size == (2, 1)
         assert (list(sgrid.tile_patterns) ==
-            [
+                [
                 ((0, 0, 2), (0, 10)),
                 ((1, 0, 2), (256, 10)),
-            ]
-        )
+                ]
+                )
         assert sgrid.bbox == (-180.0, -90.0, 3.515625, 3.515625)
 
     def test_minimal_tiles_fragmented(self):
         sgrid = self.mgrid.minimal_meta_tile(
             [
-                           (2, 3, 3),
+                (2, 3, 3),
                 (1, 2, 3),
-                           (2, 1, 3),
+                (2, 1, 3),
             ])
 
         assert sgrid.grid_size == (2, 3)
         assert (list(sgrid.tile_patterns) ==
-            [
+                [
                 ((1, 3, 3), (10, 0)), ((2, 3, 3), (266, 0)),
                 ((1, 2, 3), (10, 256)), ((2, 2, 3), (266, 256)),
                 ((1, 1, 3), (10, 512)), ((2, 1, 3), (266, 512)),
-            ]
-        )
+                ]
+                )
         assert sgrid.bbox == (-136.7578125, -46.7578125, -43.2421875, 90.0)
 
     def test_minimal_tiles_fragmented_ul(self):
         self.mgrid = MetaGrid(grid=tile_grid('EPSG:4326', origin='ul'),
-            meta_size=(2, 2), meta_buffer=10)
+                              meta_size=(2, 2), meta_buffer=10)
         sgrid = self.mgrid.minimal_meta_tile(
             [
-                           (2, 0, 3),
+                (2, 0, 3),
                 (1, 1, 3),
-                           (2, 2, 3),
+                (2, 2, 3),
             ])
 
         assert sgrid.grid_size == (2, 3)
         assert (list(sgrid.tile_patterns) ==
-            [
+                [
                 ((1, 0, 3), (10, 0)), ((2, 0, 3), (266, 0)),
                 ((1, 1, 3), (10, 256)), ((2, 1, 3), (266, 256)),
                 ((1, 2, 3), (10, 512)), ((2, 2, 3), (266, 512)),
-            ]
-        )
+                ]
+                )
         assert sgrid.bbox == (-136.7578125, -46.7578125, -43.2421875, 90.0)
 
 
@@ -438,6 +442,7 @@ class TestMetaGridLevelMetaTiles(object):
         assert meta_tiles[2] == (0, 0, 2)
         assert meta_tiles[3] == (2, 0, 2)
 
+
 class TestMetaGridLevelMetaTilesGeodetic(object):
     def setup_method(self):
         self.meta_grid = MetaGrid(TileGrid(is_geodetic=True), meta_size=(2, 2))
@@ -479,6 +484,7 @@ class TileGridTest(object):
     def check_grid(self, level, grid_size):
         assert_grid_size(self.grid, level, grid_size)
 
+
 class TestTileGridResolutions(object):
     def test_explicit_grid(self):
         grid = TileGrid(res=[0.1, 0.05, 0.01])
@@ -518,21 +524,22 @@ class TestWGS84TileGrid(object):
         assert self.grid.grid_sizes[2] == (4, 2)
 
     def test_affected_tiles(self):
-        bbox, grid, tiles = self.grid.get_affected_tiles((-180,-90,180,90), (512,256))
+        bbox, grid, tiles = self.grid.get_affected_tiles((-180, -90, 180, 90), (512, 256))
         assert bbox == (-180.0, -90.0, 180.0, 90.0)
         assert grid == (2, 1)
         assert list(tiles) == [(0, 0, 1), (1, 0, 1)]
 
     def test_affected_level_tiles(self):
-        bbox, grid, tiles = self.grid.get_affected_level_tiles((-180,-90,180,90), 1)
+        bbox, grid, tiles = self.grid.get_affected_level_tiles((-180, -90, 180, 90), 1)
         assert grid == (2, 1)
         assert bbox == (-180.0, -90.0, 180.0, 90.0)
         assert list(tiles) == [(0, 0, 1), (1, 0, 1)]
-        bbox, grid, tiles = self.grid.get_affected_level_tiles((0,0,180,90), 2)
+        bbox, grid, tiles = self.grid.get_affected_level_tiles((0, 0, 180, 90), 2)
         assert grid == (2, 1)
         assert bbox == (0.0, 0.0, 180.0, 90.0)
         assert list(tiles) == [(2, 1, 2), (3, 1, 2)]
 
+
 class TestWGS83TileGridUL(object):
     def setup_method(self):
         self.grid = TileGrid(4326, bbox=(-180, -90, 180, 90), origin='ul')
@@ -560,30 +567,31 @@ class TestWGS83TileGridUL(object):
         assert self.grid.grid_sizes[2] == (4, 2)
 
     def test_affected_tiles(self):
-        bbox, grid, tiles = self.grid.get_affected_tiles((-180,-90,180,90), (512,256))
+        bbox, grid, tiles = self.grid.get_affected_tiles((-180, -90, 180, 90), (512, 256))
         assert bbox == (-180.0, -90.0, 180.0, 90.0)
         assert grid == (2, 1)
         assert list(tiles) == [(0, 0, 1), (1, 0, 1)]
 
-        bbox, grid, tiles = self.grid.get_affected_tiles((-180,-90,0,90), (512, 512))
+        bbox, grid, tiles = self.grid.get_affected_tiles((-180, -90, 0, 90), (512, 512))
         assert bbox == (-180.0, -90.0, 0.0, 90.0)
         assert grid == (2, 2)
         assert list(tiles) == [(0, 0, 2), (1, 0, 2), (0, 1, 2), (1, 1, 2)]
 
     def test_affected_level_tiles(self):
-        bbox, grid, tiles = self.grid.get_affected_level_tiles((-180,-90,180,90), 1)
+        bbox, grid, tiles = self.grid.get_affected_level_tiles((-180, -90, 180, 90), 1)
         assert grid == (2, 1)
         assert bbox == (-180.0, -90.0, 180.0, 90.0)
         assert list(tiles) == [(0, 0, 1), (1, 0, 1)]
-        bbox, grid, tiles = self.grid.get_affected_level_tiles((0,0,180,90), 2)
+        bbox, grid, tiles = self.grid.get_affected_level_tiles((0, 0, 180, 90), 2)
         assert grid == (2, 1)
         assert list(tiles) == [(2, 0, 2), (3, 0, 2)]
         assert bbox == (0.0, 0.0, 180.0, 90.0)
-        bbox, grid, tiles = self.grid.get_affected_level_tiles((0,-90,180,90), 2)
+        bbox, grid, tiles = self.grid.get_affected_level_tiles((0, -90, 180, 90), 2)
         assert grid == (2, 2)
         assert list(tiles) == [(2, 0, 2), (3, 0, 2), (2, 1, 2), (3, 1, 2)]
         assert bbox == (0.0, -90.0, 180.0, 90.0)
 
+
 class TestGKTileGrid(TileGridTest):
     def setup_method(self):
         self.grid = TileGrid(SRS(31467), bbox=(3250000, 5230000, 3930000, 6110000))
@@ -607,7 +615,6 @@ class TestGKTileGrid(TileGridTest):
         assert [self.grid.tile(x, y, level) for level in range(5)] == \
             [(0, 0, 0), (0, 1, 1), (0, 3, 2), (1, 6, 3), (3, 12, 4)]
 
-
     @pytest.mark.parametrize('level,grid_size', [
         (0, (1, 1)),
         (1, (2, 2)),
@@ -638,21 +645,22 @@ class TestGKTileGridUL(TileGridTest):
     """
     Custom grid with ul origin.
     """
+
     def setup_method(self):
         self.grid = TileGrid(SRS(31467),
-            bbox=(3300000, 5300000, 3900000, 6000000), origin='ul',
-            res=[1500, 1000, 500, 300, 150, 100])
+                             bbox=(3300000, 5300000, 3900000, 6000000), origin='ul',
+                             res=[1500, 1000, 500, 300, 150, 100])
 
     def test_bbox(self):
         assert self.grid.bbox == (3300000, 5300000, 3900000, 6000000)
 
     def test_tile_bbox(self):
         assert (self.grid.tile_bbox((0, 0, 0)) ==
-            (3300000.0, 5616000.0, 3684000.0, 6000000.0))
+                (3300000.0, 5616000.0, 3684000.0, 6000000.0))
         assert (self.grid.tile_bbox((1, 0, 0)) ==
-            (3684000.0, 5616000.0, 4068000.0, 6000000.0))
+                (3684000.0, 5616000.0, 4068000.0, 6000000.0))
         assert (self.grid.tile_bbox((1, 1, 0)) ==
-            (3684000.0, 5232000.0, 4068000.0, 5616000.0))
+                (3684000.0, 5232000.0, 4068000.0, 5616000.0))
 
     def test_tile(self):
         x, y = 3310000, 5990000
@@ -690,8 +698,11 @@ class TestGKTileGridUL(TileGridTest):
 class TestClosestLevelTinyResFactor(object):
     def setup_method(self):
         self.grid = TileGrid(SRS(31467),
-            bbox=[420000,30000,900000,350000], origin='ul',
-            res=[4000,3750,3500,3250,3000,2750,2500,2250,2000,1750,1500,1250,1000,750,650,500,250,100,50,20,10,5,2.5,2,1.5,1,0.5],
+                             bbox=[420000, 30000, 900000, 350000],
+                             origin='ul',
+                             res=[
+            4000, 3750, 3500, 3250, 3000, 2750, 2500, 2250, 2000, 1750, 1500, 1250, 1000, 750, 650, 500, 250, 100,
+            50, 20, 10, 5, 2.5, 2, 1.5, 1, 0.5],
         )
 
     def test_closest_level(self):
@@ -715,12 +726,12 @@ class TestOrigins(object):
 
     def test_basic_no_level_zero(self):
         grid = tile_grid(4326, bbox=(-180, -90, 180, 90), origin='ll',
-            min_res=360/256/2)
+                         min_res=360/256/2)
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
         grid = tile_grid(4326, bbox=(-180, -90, 180, 90), origin='ul',
-            min_res=360/256/2)
+                         min_res=360/256/2)
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
@@ -736,49 +747,50 @@ class TestOrigins(object):
     def test_custom_with_match(self):
         # height is divisible by res*tile_size
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1024), origin='ll',
-            min_res=1)
+                         min_res=1)
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1024), origin='ul',
-            min_res=1)
+                         min_res=1)
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
     def test_custom_without_match(self):
         # height is not divisible by res*tile_size
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1000), origin='ll',
-            min_res=1)
+                         min_res=1)
         assert grid.supports_access_with_origin('ll')
         assert not grid.supports_access_with_origin('ul')
 
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1000), origin='ul',
-            min_res=1)
+                         min_res=1)
         assert not grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
     def test_custom_res_with_match(self):
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1024), origin='ll',
-            res=[1, 0.5, 0.25])
+                         res=[1, 0.5, 0.25])
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1024), origin='ul',
-            res=[1, 0.5, 0.25])
+                         res=[1, 0.5, 0.25])
         assert grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
     def test_custom_res_without_match(self):
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1023), origin='ll',
-            res=[1, 0.5, 0.25])
+                         res=[1, 0.5, 0.25])
         assert grid.supports_access_with_origin('ll')
         assert not grid.supports_access_with_origin('ul')
 
         grid = tile_grid(4326, bbox=(0, 0, 1024, 1023), origin='ul',
-            res=[1, 0.5, 0.25])
+                         res=[1, 0.5, 0.25])
         assert not grid.supports_access_with_origin('ll')
         assert grid.supports_access_with_origin('ul')
 
+
 class TestFixedResolutionsTileGrid(TileGridTest):
     def setup_method(self):
         self.res = [1000.0, 500.0, 200.0, 100.0, 50.0, 20.0, 5.0]
@@ -830,16 +842,18 @@ class TestFixedResolutionsTileGrid(TileGridTest):
         self.check_grid(level, grid_size)
 
     def test_tile_bbox(self):
-        tile_bbox = self.grid.tile_bbox((0, 0, 0)) # w: 1000x256
+        tile_bbox = self.grid.tile_bbox((0, 0, 0))  # w: 1000x256
         assert tile_bbox == (3250000.0, 5230000.0, 3506000.0, 5486000.0)
-        tile_bbox = self.grid.tile_bbox((0, 0, 1)) # w: 500x256
+        tile_bbox = self.grid.tile_bbox((0, 0, 1))  # w: 500x256
         assert tile_bbox == (3250000.0, 5230000.0, 3378000.0, 5358000.0)
-        tile_bbox = self.grid.tile_bbox((0, 0, 2)) # w: 200x256
+        tile_bbox = self.grid.tile_bbox((0, 0, 2))  # w: 200x256
         assert tile_bbox == (3250000.0, 5230000.0, 3301200.0, 5281200.0)
 
+
 class TestGeodeticTileGrid(TileGridTest):
     def setup_method(self):
         self.grid = TileGrid(is_geodetic=True, )
+
     def test_auto_resolution(self):
         grid = TileGrid(is_geodetic=True, bbox=(-10, 30, 10, 40), tile_size=(20, 20))
         tile_bbox = grid.tile_bbox((0, 0, 0))
@@ -882,13 +896,14 @@ class TestGeodeticTileGrid(TileGridTest):
 
     def test_affected_tiles(self):
         bbox, grid_size, tiles = \
-            self.grid.get_affected_tiles((-45,-45,45,45), (512,512))
+            self.grid.get_affected_tiles((-45, -45, 45, 45), (512, 512))
         assert self.grid.grid_sizes[3] == (8, 4)
         assert bbox == (-45.0, -45.0, 45.0, 45.0)
         assert grid_size == (2, 2)
         tiles = list(tiles)
         assert tiles == [(3, 2, 3), (4, 2, 3), (3, 1, 3), (4, 1, 3)]
 
+
 class TestTileGrid(object):
     def test_tile_out_of_grid_bounds(self):
         grid = TileGrid(is_geodetic=True)
@@ -896,7 +911,7 @@ class TestTileGrid(object):
 
     def test_affected_tiles_out_of_grid_bounds(self):
         grid = TileGrid()
-        #bbox from open layers
+        # bbox from open layers
         req_bbox = (-30056262.509599999, -10018754.170400001, -20037508.339999996, -0.00080000050365924835)
         bbox, grid_size, tiles = \
             grid.get_affected_tiles(req_bbox, (256, 256))
@@ -907,7 +922,7 @@ class TestTileGrid(object):
 
     def test_broken_bbox(self):
         grid = TileGrid()
-        req_bbox = (-20000855.0573254,2847125.18913603,-19329367.42767611,4239924.78564583)
+        req_bbox = (-20000855.0573254, 2847125.18913603, -19329367.42767611, 4239924.78564583)
         try:
             grid.get_affected_tiles(req_bbox, (256, 256), req_srs=SRS(31467))
         except TransformationError:
@@ -915,6 +930,7 @@ class TestTileGrid(object):
         else:
             assert False, 'Expected TransformationError'
 
+
 class TestTileGridThreshold(object):
     def test_lower_bound(self):
         # thresholds near the next lower res value
@@ -936,6 +952,7 @@ class TestTileGridThreshold(object):
         # regular transition (w/stretchfactor)
         assert grid.closest_level(92) == 3
         assert grid.closest_level(90) == 4
+
     def test_upper_bound(self):
         # thresholds near the next upper res value (within threshold)
         grid = TileGrid(res=[1000, 500, 250, 100, 50], threshold_res=[495, 240])
@@ -956,6 +973,7 @@ class TestTileGridThreshold(object):
         # regular transition (w/stretchfactor)
         assert (grid.closest_level(92) == 3)
         assert (grid.closest_level(90) == 4)
+
     def test_above_first_res(self):
         grid = TileGrid(res=[1000, 500, 250, 100, 50], threshold_res=[1100, 750])
         grid.stretch_factor = 1.1
@@ -1073,39 +1091,42 @@ class TestBBOXContains(object):
         assert not bbox_contains(b1, b2)
         assert not bbox_contains(b2, b1)
 
+
 def assert_almost_equal_bbox(bbox1, bbox2, rel=0.01):
     assert bbox1 == pytest.approx(bbox2, rel=rel)
 
+
 class TestResolutionRange(object):
     def test_meter(self):
         res_range = ResolutionRange(1000, 10)
         assert not res_range.contains([0, 0, 100000, 100000], (10, 10), SRS(900913))
         assert not res_range.contains([0, 0, 100000, 100000], (99, 99), SRS(900913))
         # min is exclusive but there is a delta
-        assert     res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
         # max is inclusive
-        assert     res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
         assert not res_range.contains([0, 0, 100000, 100000], (10001, 10001), SRS(900913))
+
     def test_deg(self):
         res_range = ResolutionRange(100000, 1000)
         assert not res_range.contains([0, 0, 10, 10], (10, 10), SRS(4326))
         assert not res_range.contains([0, 0, 10, 10], (11, 11), SRS(4326))
-        assert     res_range.contains([0, 0, 10, 10], (12, 12), SRS(4326))
-        assert     res_range.contains([0, 0, 10, 10], (100, 100), SRS(4326))
-        assert     res_range.contains([0, 0, 10, 10], (1000, 1000), SRS(4326))
-        assert     res_range.contains([0, 0, 10, 10], (1100, 1100), SRS(4326))
+        assert res_range.contains([0, 0, 10, 10], (12, 12), SRS(4326))
+        assert res_range.contains([0, 0, 10, 10], (100, 100), SRS(4326))
+        assert res_range.contains([0, 0, 10, 10], (1000, 1000), SRS(4326))
+        assert res_range.contains([0, 0, 10, 10], (1100, 1100), SRS(4326))
         assert not res_range.contains([0, 0, 10, 10], (1200, 1200), SRS(4326))
 
     def test_no_min(self):
         res_range = ResolutionRange(None, 10)
-        assert     res_range.contains([0, 0, 100000, 100000], (1, 1), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (10, 10), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (99, 99), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (1, 1), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (10, 10), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (99, 99), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
         # max is inclusive
-        assert     res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
         assert not res_range.contains([0, 0, 100000, 100000], (10001, 10001), SRS(900913))
 
     def test_no_max(self):
@@ -1113,15 +1134,15 @@ class TestResolutionRange(object):
         assert not res_range.contains([0, 0, 100000, 100000], (10, 10), SRS(900913))
         assert not res_range.contains([0, 0, 100000, 100000], (99, 99), SRS(900913))
         # min is exclusive but there is a delta
-        assert     res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (10001, 10001), SRS(900913))
-        assert     res_range.contains([0, 0, 100000, 100000], (1000000, 100000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (100, 100), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (1000, 1000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (10000, 10000), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (10001, 10001), SRS(900913))
+        assert res_range.contains([0, 0, 100000, 100000], (1000000, 100000), SRS(900913))
 
     def test_none(self):
         res_range = resolution_range(None, None)
-        assert res_range == None
+        assert res_range is None
 
     def test_from_scale(self):
         res_range = resolution_range(max_scale=1e6, min_scale=1e3)
@@ -1149,12 +1170,12 @@ class TestResolutionRange(object):
     def test_merge_resolutions(self):
         res_range = merge_resolution_range(
             ResolutionRange(None, 10), ResolutionRange(1000, None))
-        assert res_range == None
+        assert res_range is None
 
         res_range = merge_resolution_range(
             ResolutionRange(10000, 10), ResolutionRange(1000, None))
         assert res_range.min_res == 10000
-        assert res_range.max_res == None
+        assert res_range.max_res is None
 
         res_range = merge_resolution_range(
             ResolutionRange(10000, 10), ResolutionRange(1000, 1))
@@ -1163,15 +1184,15 @@ class TestResolutionRange(object):
 
         res_range = merge_resolution_range(
             ResolutionRange(10000, 10), ResolutionRange(None, None))
-        assert res_range == None
+        assert res_range is None
 
         res_range = merge_resolution_range(
             None, ResolutionRange(None, None))
-        assert res_range == None
+        assert res_range is None
 
         res_range = merge_resolution_range(
             ResolutionRange(10000, 10), None)
-        assert res_range == None
+        assert res_range is None
 
     def test_eq(self):
         assert resolution_range(None, None) == resolution_range(None, None)
@@ -1220,7 +1241,7 @@ class TestGridSubset(object):
         assert g1.is_subset_of(g2)
 
         g1 = tile_grid(SRS(3857), bbox=[0, 0, 20037508.342789244, 20037508.342789244],
-            min_res=78271.51696402048, num_levels=18)
+                       min_res=78271.51696402048, num_levels=18)
         g2 = tile_grid(SRS(3857), origin='nw')
         assert g1.is_subset_of(g2)
 
@@ -1244,9 +1265,9 @@ class TestGridSubset(object):
 
     def test_non_matching_bboxfor_origins(self):
         g1 = tile_grid(SRS(21781), bbox=[420000, 30000, 900000, 360000],
-            res=[250], origin='nw')
+                       res=[250], origin='nw')
         g2 = tile_grid(SRS(21781), bbox=[420000, 30000, 900000, 360000],
-            res=[250], origin='sw')
+                       res=[250], origin='sw')
 
         assert not g1.is_subset_of(g2)
 
